Array

Enum Array 

#[non_exhaustive]
pub enum Array {
Show 38 variants Null(NullArray), Boolean(BooleanArray), Int8(PrimitiveArray<i8>), Int16(PrimitiveArray<i16>), Int32(PrimitiveArray<i32>), Int64(PrimitiveArray<i64>), UInt8(PrimitiveArray<u8>), UInt16(PrimitiveArray<u16>), UInt32(PrimitiveArray<u32>), UInt64(PrimitiveArray<u64>), Float16(PrimitiveArray<f16>), Float32(PrimitiveArray<f32>), Float64(PrimitiveArray<f64>), Date32(PrimitiveArray<i32>), Date64(PrimitiveArray<i64>), Time32(TimeArray<i32>), Time64(TimeArray<i64>), Timestamp(TimestampArray), Duration(TimeArray<i64>), YearMonthInterval(PrimitiveArray<i32>), DayTimeInterval(PrimitiveArray<DayTimeInterval>), MonthDayNanoInterval(PrimitiveArray<MonthDayNanoInterval>), Utf8(BytesArray<i32>), LargeUtf8(BytesArray<i64>), Utf8View(BytesViewArray), Binary(BytesArray<i32>), LargeBinary(BytesArray<i64>), FixedSizeBinary(FixedSizeBinaryArray), BinaryView(BytesViewArray), Decimal128(DecimalArray<i128>), Struct(StructArray), List(ListArray<i32>), LargeList(ListArray<i64>), FixedSizeList(FixedSizeListArray), Dictionary(DictionaryArray), RunEndEncoded(RunEndEncodedArray), Map(MapArray), Union(UnionArray),
}
An array with owned data

The corresponding view is View.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Null(NullArray)

An array without data



Boolean(BooleanArray)

bool array



Int8(PrimitiveArray<i8>)

i8 array



Int16(PrimitiveArray<i16>)

i16 array



Int32(PrimitiveArray<i32>)

i32 array



Int64(PrimitiveArray<i64>)

i64 array



UInt8(PrimitiveArray<u8>)

u8 array



UInt16(PrimitiveArray<u16>)

u16 array



UInt32(PrimitiveArray<u32>)

u32 array



UInt64(PrimitiveArray<u64>)

u64 array



Float16(PrimitiveArray<f16>)

f16 array



Float32(PrimitiveArray<f32>)

f32 array



Float64(PrimitiveArray<f64>)

f64 array



Date32(PrimitiveArray<i32>)

An i32 array of dates



Date64(PrimitiveArray<i64>)

An i64 array of dates



Time32(TimeArray<i32>)

An i32 array of times



Time64(TimeArray<i64>)

An i64 array of times



Timestamp(TimestampArray)

An i64 array of timestamps



Duration(TimeArray<i64>)

An i64 array of durations



YearMonthInterval(PrimitiveArray<i32>)

Interval with YearMonth unit

Interval arrays are not supported for arrow2.



DayTimeInterval(PrimitiveArray<DayTimeInterval>)

Interval with DayTime unit

Interval arrays are not supported for arrow2.



MonthDayNanoInterval(PrimitiveArray<MonthDayNanoInterval>)

Interval with MonthDayNano unit

Interval arrays are not supported for arrow2.



Utf8(BytesArray<i32>)

A [u8] array with i32 offsets interpreted as strings



LargeUtf8(BytesArray<i64>)

A [u8] array with i64 offsets interpreted as strings



Utf8View(BytesViewArray)

A [u8] array interpreted as strings with support for small inlined slices and references to external buffers



Binary(BytesArray<i32>)

A [u8] array with i32 offsets



LargeBinary(BytesArray<i64>)

A [u8] array with i64 offsets



FixedSizeBinary(FixedSizeBinaryArray)

A [u8; N] array with i32 offsets



BinaryView(BytesViewArray)

A [u8] array with support for small inlined slices and references to external buffers



Decimal128(DecimalArray<i128>)

An i128 array of decimals



Struct(StructArray)

An array of structs



List(ListArray<i32>)

An array of lists with i32 offsets



LargeList(ListArray<i64>)

An array of lists with i64 offsets



FixedSizeList(FixedSizeListArray)

An array of fixed sized list with i32 offsets



Dictionary(DictionaryArray)

An array of dictionaries



RunEndEncoded(RunEndEncodedArray)

An array of run end encoded values



Map(MapArray)

An array of maps



Union(UnionArray)

An array of unions

Implementations

Source

impl Array

pub fn data_type(&self) -> DataType

Get the data type of this array

pub fn as_view(&self) -> View<'_>

Get the view for this array

While the data of the arrays is borrowed, any metadata is copied (e.g., field definitions for structs). The reason is that views may be constructed from foreign Arrow implementation with different ways to store metadata.