#[non_exhaustive]pub enum DataType {
Show 36 variants
Null,
Boolean,
Int8,
Int16,
Int32,
Int64,
UInt8,
UInt16,
UInt32,
UInt64,
Float16,
Float32,
Float64,
Utf8,
LargeUtf8,
Utf8View,
Binary,
LargeBinary,
BinaryView,
FixedSizeBinary(i32),
Date32,
Date64,
Timestamp(TimeUnit, Option<String>),
Time32(TimeUnit),
Time64(TimeUnit),
Duration(TimeUnit),
Interval(IntervalUnit),
Decimal128(u8, i8),
Struct(Vec<Field>),
List(Box<Field>),
LargeList(Box<Field>),
FixedSizeList(Box<Field>, i32),
Map(Box<Field>, bool),
Dictionary(Box<DataType>, Box<DataType>),
RunEndEncoded(Box<Field>, Box<Field>),
Union(Vec<(i8, Field)>, UnionMode),
}Expand description
Data types of array
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Null
Data type for fields without data
Boolean
bool values stored as bitmaps
Int8
i8 stored as a contiguous array
Int16
i16 stored as a contiguous array
Int32
i32 stored as a contiguous array
Int64
i64 stored as a contiguous array
UInt8
u8 stored as a contiguous array
UInt16
u16 stored as a contiguous array
UInt32
u32 stored as a contiguous array
UInt64
u64 stored as a contiguous array
Float16
f16 stored as a contiguous array
Float32
f32 stored as a contiguous array
Float64
f64 stored as a contiguous array
Utf8
Strings stored with i32 offsets
LargeUtf8
Strings stored with i64 offsets
Utf8View
Strings stored with i32 offsets or inline for small strings
Binary
Byte arrays stored with i32 offsets
LargeBinary
Byte arrays stored with i64 offsets
BinaryView
Bytes stored with u32 offsets or inline for small values
FixedSizeBinary(i32)
Byte arrays with fixed length
Date32
Dates as the number of days since the epoch stored as i32 (e.g., "2022-10-11")
Date64
Dates as the number of seconds since the epoch stored as i64 (e.g., "2022-10-11")
Timestamp(TimeUnit, Option<String>)
A UTC timestamps stored as i64 with the specified unit and an optional timezone
Time32(TimeUnit)
Times as an offset from midnight stored as i32 with the given unit
Time64(TimeUnit)
Times as an offset from midnight stored as i64 with the given unit
Duration(TimeUnit)
Durations stored as i64 with the given unit
Interval(IntervalUnit)
Calendar intervals with different layouts depending on the given unit
Decimal128(u8, i8)
Fixed point values stored with the given precision and scale
Struct(Vec<Field>)
Structs
List(Box<Field>)
Lists with i32 offsets
LargeList(Box<Field>)
Lists with i64 offsets
FixedSizeList(Box<Field>, i32)
Lists with a fixed number of element with i32 offsets
Map(Box<Field>, bool)
Maps
The field should be a struct field with two children for the keys and values.
Dictionary(Box<DataType>, Box<DataType>)
Deduplicated values
The children are Dictionary(indices, values)
RunEndEncoded(Box<Field>, Box<Field>)
Deduplicated values that continuously repeat
The children are RunEndEncoded(indices, values)
Union(Vec<(i8, Field)>, UnionMode)
Union o different types